# LogHandlingModule
LH Module - With debugging. 
# Simple Use - More detail coming soon
```pip install Simple-LogHandler```
```python
from Simple-LogHandler import LogHandler
log = LogHandler.loghandle()
log.pathset(r'PATH')
log.log('ERROR')
# Will Output detailed error log To Log File Based on Date.
# ERRORs can be Bools, Strings, and Integers - Will be translated to string forms and output.
# More features to come!
```
